.tree-view .MuiTreeItem-root{padding-left:1rem;position:relative}.tree-view .MuiFormControlLabel-label,.tree-view .MuiTreeItem-label,.tree-view .MuiTypography-root{font-size:.8rem}.tree-view .MuiTreeItem-group{padding-left:1rem;position:relative}.MuiTreeItem-content,.MuiTypography-root.MuiTreeItem-label.MuiTypography-body1{height:2.5rem}.tree-view .MuiTreeItem-content:not(.no-before):before{content:"";height:.9rem;left:0;position:absolute;top:.85rem;transform:translateY(-50%);width:1.5rem}.tree-view .MuiFormControlLabel-root{align-items:center;display:flex;justify-content:flex-start;position:relative;text-align:left;top:-.08rem;width:fit-content}#disabled_div_enable{opacity:.5;pointer-events:none}span>div>svg.MuiSvgIcon-root{scale:.8}.y_scroll_enable{max-height:100%;overflow-y:scroll}.x_scroll_enable{max-width:100%;overflow-x:scroll}.y_scroll_disable{overflow-y:hidden}.x_scroll_disable{overflow-x:hidden}
/*# sourceMappingURL=main.2d85aae4.css.map*/